# seismic-toolbox

The purpose of this repository is to be used as 
an open-source library as a base others projects, sometimes
closed source.
This toolbox relies only on numpy 
(and possibly pandas in the future).

Packages include:
-   reader: a seg reader interface and a seg-y implementation.

## Installation

### User mode
`pip install seismic`

### Dev mode
Clone the repository, activate your environment, cd to 
the `seismic-toolbox` directory and install using:

`pip install -e .`
